use strict;
use warnings;
use Test::More;

BEGIN {
  unless ($ENV{RELEASE_TESTING}) {
    plan skip_all => 'these tests are for release candidate testing';
  }
}

eval "use Test::Pod 1.41";
plan skip_all => "Test::Pod 1.41 required for testing POD" if $@;

all_pod_files_ok();
